module NgAttributes
  class Railtie < ::Rails::Railtie #:nodoc:
    config.after_initialize do

      module ActionView::Helpers::TagHelper
        private

        def tag_options(options, escape = true)
          return if options.blank?
          attrs = []
          options.each_pair do |key, value|
            if key.to_s == 'data' && value.is_a?(Hash)
              value.each_pair do |k, v|
                attrs << data_tag_option(k, v, escape)
              end
            elsif key.to_s == 'ng' && value.is_a?(Hash)
              value.each_pair do |k, v|
                attrs << ng_tag_option(k, v, escape)
              end
            elsif BOOLEAN_ATTRIBUTES.include?(key)
              attrs << boolean_tag_option(key) if value
            elsif !value.nil?
              attrs << tag_option(key, value, escape)
            end
          end
          " #{attrs.sort! * ' '}".html_safe unless attrs.empty?
        end

        ['ng', 'data'].each do |method_name|
          define_method("#{method_name}_tag_option") do |key, value, escape|
            key = "#{method_name}-#{key.to_s.dasherize}"
            unless value.is_a?(String) || value.is_a?(Symbol) || value.is_a?(BigDecimal)
              value = value.to_json
            end
            tag_option(key, value, escape)
          end
        end

        def boolean_tag_option(key)
          %(#{key}="#{key}")
        end

        def tag_option(key, value, escape)
          value = value.join(" ") if value.is_a?(Array)
          value = ERB::Util.h(value) if escape
          %(#{key}="#{value}")
        end
      end
    end

  end
end
